package com.aliyun.odps.spark.examples.myUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.Column;
import com.aliyun.odps.data.Record;
import com.google.gson.Gson;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;

public class ConvertUtils {
    public static Set<String> getVidList(String data) {
        Set<String> vidList = new HashSet<>();
        if (null != data && !data.isEmpty()) {
            UserShareReturnProfile user = JSON.parseObject(data, UserShareReturnProfile.class);
            if (null != user) {
                for (List<UserSRBO> list : Arrays.asList(user.getM_s_s(), user.getM_r_s(), user.getL_s_s(), user.getL_r_s())) {
                    if (null != list) {
                        for (UserSRBO u : list) {
                            if (null != u) {
                                vidList.add(u.getId() + "");
                            }
                        }
                    }
                }
            }
        }
        return vidList;
    }

    public static Map<String, String> getRecordCol(Record record, String col) {
        Map<String, String> colMap = new HashMap<>();
        if (null != record && !record.isNull(col)) {
            try {
                JSONObject json = JSON.parseObject(record.getString(col));
                if (null != json) {
                    for (Map.Entry<String, Object> entry : json.entrySet()) {
                        Object obj = entry.getValue();
                        if (null != obj) {
                            colMap.put(entry.getKey(), obj.toString());
                        }
                    }
                }
            } catch (Exception ignored) {
            }
        }
        return colMap;
    }

    public static Map<String, String> getRecordCol(Map<String, String> record, String col) {
        Map<String, String> colMap = new HashMap<>();
        if (null != record && record.containsKey(col)) {
            try {
                JSONObject json = JSON.parseObject(record.get(col));
                if (null != json) {
                    for (Map.Entry<String, Object> entry : json.entrySet()) {
                        Object obj = entry.getValue();
                        if (null != obj) {
                            colMap.put(entry.getKey(), obj.toString());
                        }
                    }
                }
            } catch (Exception ignored) {
            }
        }
        return colMap;
    }

    public static Map<String, String> record2Map(Record record, Set<String> filterColumns) {
        Map<String, String> map = new HashMap<>();
        if (null != record) {
            Column[] columns = record.getColumns();
            if (null != columns) {
                for (Column column : columns) {
                    String name = column.getName();
                    if (filterColumns.contains(name)) {
                        continue;
                    }
                    if (!record.isNull(name)) {
                        map.put(name, record.getString(name));
                    }
                }
            }
        }
        return map;
    }

    public static Map<String, Map<String, String>> list2Map(List<Map<String, String>> videSeq) {
        Map<String, Map<String, String>> map = new HashMap<>();
        if (null != videSeq && !videSeq.isEmpty()) {
            for (Map<String, String> video : videSeq) {
                if (null != video && !video.isEmpty()) {
                    String vid = video.get("vid");
                    if (null != vid && !vid.isEmpty()) {
                        map.put(video.get("vid"), video);
                    }
                }
            }
        }
        return map;
    }

    public static JSONObject filterAndTruncate(Map<String, Double> featMap, int scale) {
        JSONObject jsonObject = new JSONObject();
        for (Map.Entry<String, Double> entry : featMap.entrySet()) {
            double value = entry.getValue();
            if (value > 1E-8) {
                if (value == Math.floor(value)) {
                    jsonObject.put(entry.getKey(), entry.getValue());
                } else {
                    double newValue = new BigDecimal(value).setScale(scale, RoundingMode.HALF_UP).doubleValue();
                    jsonObject.put(entry.getKey(), newValue);
                }
            }
        }
        return jsonObject;
    }

    public static String toJson(Object obj) {
        if (obj == null) {
            return "";
        }
        try {
            return new Gson().toJson(obj);
        } catch (Exception e) {
            return "";
        }
    }
}
